//	app.cpp - Main application stuff.
//	----------------------------------------------------------------------------
//	This file is part of Mouse To OSC, a simple OSC-outputting program.
//	Copyright (c) 2006 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#include <juce.h>
#include "app.h"
#include "window.h"

///-----------------------------------------------------------------------------
void App::initialise(const String& commandLine)
{
	WindowContents *tempComp;

	LookAndFeel::setDefaultLookAndFeel(shiny = new ShinyLookAndFeel());

	commands = new ApplicationCommandManager();

	win = new DialogWindow(T("Mouse To OSC"), Colours::lightblue, false);
	win->getCloseButton()->addButtonListener(this);
	win->setContentComponent(tempComp = new WindowContents());
	win->setMenuBar(tempComp, commands, 24);
	win->centreWithSize(800, 600);
	win->setVisible(true);
}

///-----------------------------------------------------------------------------
void App::shutdown()
{
	delete win;
	delete shiny;
	delete commands;
}

///-----------------------------------------------------------------------------
void App::buttonClicked(Button *button)
{
	JUCEApplication::quit();
}

START_JUCE_APPLICATION(App)
